@@ -8,19 +8,17 @@ from sqlalchemy.sql import sqltypes
 
 from pytech.sqlalchemy_tools.models import BaseSqlModel
 
-__all__ = [
-    "build_sqlalchemy_model"
-]
+__all__ = ["build_sqlalchemy_model"]
 
 
-def build_sqlalchemy_model( # noqa: PLR0912, PLR0913
-        from_dataclass: type,
-        table_name: str,
-        model_name: str,
-        additional_fields: dict | None = None,
-        pk_fields: list | None = None,
-        unique_fields: list | None = None,
-        extensible_model: bool = False
+def build_sqlalchemy_model(  # noqa: PLR0912, PLR0913
+    from_dataclass: type,
+    table_name: str,
+    model_name: str,
+    additional_fields: dict | None = None,
+    pk_fields: list | None = None,
+    unique_fields: list | None = None,
+    extensible_model: bool = False,
 ) -> BaseSqlModel:
     """
     Dynamically creates a SQLAlchemy model from a provided dataclass.
@@ -85,23 +83,20 @@ def build_sqlalchemy_model( # noqa: PLR0912, PLR0913
 
     model_attrs = {
         "__tablename__": table_name,
-        "__annotations__": {
-            k: Mapped[v.type] for k, v in _dataclass_fields.items()
-        }
+        "__annotations__": {k: Mapped[v.type] for k, v in _dataclass_fields.items()},
     }
 
     if additional_fields:
         # If additional_fields are defined we check they are well-defined
-        if not all([
-            set(field_name).issubset(f"_{ascii_letters}")
-            for field_name in additional_fields
-        ]):
+        if not all(
+            [
+                set(field_name).issubset(f"_{ascii_letters}")
+                for field_name in additional_fields
+            ]
+        ):
             raise ValueError("'additional_fields' contains invalid characters.")
 
-        if not all([
-            isinstance(field, Column)
-            for field in additional_fields.values()
-        ]):
+        if not all([isinstance(field, Column) for field in additional_fields.values()]):
             raise ValueError("'additional_fields' must be valid Columns")
 
         model_attrs |= additional_fields
@@ -112,9 +107,7 @@ def build_sqlalchemy_model( # noqa: PLR0912, PLR0913
             raise ValueError("'pk_fields' must be a list of valid keys.")
 
         model_attrs |= {
-            "__mapper_args__": {
-                "primary_key": pk_fields
-            },
+            "__mapper_args__": {"primary_key": pk_fields},
         }
 
     table_args = []
@@ -126,13 +119,6 @@ def build_sqlalchemy_model( # noqa: PLR0912, PLR0913
     if extensible_model:
         table_args.append({"extend_existing": True})
 
-    model_attrs |= {
-        "__table_args__": tuple(table_args)
-    }
+    model_attrs |= {"__table_args__": tuple(table_args)}
 
-
-    return type(
-        model_name,
-        (BaseSqlModel,),
-        model_attrs
-    )
+    return type(model_name, (BaseSqlModel,), model_attrs)
